==> haskell-data-textual-0.3.0.3-456-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-NJqKJlnm6H2j29tDd1ziv
key:                  data-textual-0.3.0.3-NJqKJlnm6H2j29tDd1ziv
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  3ca29ae1e8adac56364066124bdd2233
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-NJqKJlnm6H2j29tDd1ziv
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    parsers-0.12.12-DfYdVEQmGRRB46RG1X00Px text-2.0.2
    text-latin1-0.3.1-J81rCj0QIjR7NbtQznblwg
    text-printer-0.5.0.2-K0VrJjE7oTG5FOFkZUnMXr

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.3-457-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-ChwC84R3abKGXQSZPhNjWw
key:                  data-textual-0.3.0.3-ChwC84R3abKGXQSZPhNjWw
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  1460b1ce6421a0c179b27b65f50fa0f5
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-ChwC84R3abKGXQSZPhNjWw
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    parsers-0.12.12-9uOKlEBWK86NuVEBiBC6i text-2.0.2
    text-latin1-0.3.1-2uxJ7Jddk9zIql9Md0i8Kx
    text-printer-0.5.0.2-GTVKwyBLNpQEwB0XOeCxF2

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
